@@ -5,27 +5,37 @@
  */
 
 #include <QApplication>
-#include <QIcon>
-#include <QQmlApplicationEngine>
 #include <QCommandLineParser>
+#include <QIcon>
+#include <QProcess>
+#include <QQmlApplicationEngine>
 #include <QQmlContext>
 #include <QQuickStyle>
 #include <QStandardPaths>
-#include <QProcess>
 
 #include <KAboutData>
-#include <KLocalizedString>
-#include <KLocalizedContext>
 #include <KColorSchemeManager>
+#include <KLocalizedContext>
+#include <KLocalizedString>
+#include "kdeconnect-version.h"
 
-int main(int argc, char* argv[])
+int main(int argc, char *argv[])
 {
     QIcon::setFallbackThemeName(QStringLiteral("breeze"));
+    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+    QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
 
     QApplication app(argc, argv);
+    KLocalizedString::setApplicationDomain("kdeconnect-app");
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("kdeconnect")));
-    KAboutData aboutData(QStringLiteral("kdeconnect.app"), i18n("KDE Connect"), QStringLiteral("1.0"), i18n("KDE Connect"), KAboutLicense::GPL, i18n("(c) 2015, Aleix Pol Gonzalez"));
+    KAboutData aboutData(QStringLiteral("kdeconnect.app"),
+                         i18n("KDE Connect"),
+                         QStringLiteral(KDE_CONNECT_VERSION_STRING),
+                         i18n("KDE Connect"),
+                         KAboutLicense::GPL,
+                         i18n("(c) 2015, Aleix Pol Gonzalez"));
     aboutData.addAuthor(i18n("Aleix Pol Gonzalez"), i18n("Maintainer"), QStringLiteral("aleixpol@kde.org"));
+    aboutData.setTranslator(i18nc("NAME OF TRANSLATORS", "Your names"), i18nc("EMAIL OF TRANSLATORS", "Your emails"));
     KAboutData::setApplicationData(aboutData);
 
 #ifdef Q_OS_WIN
@@ -47,14 +57,19 @@ int main(int argc, char* argv[])
         aboutData.processCommandLine(&parser);
         if (parser.positionalArguments().count() == 1) {
             urlToShare = parser.positionalArguments().constFirst();
-            const QString kdeconnectHandlerExecutable = QStandardPaths::findExecutable(QStringLiteral("kdeconnect-handler"), { QCoreApplication::applicationDirPath() });
+            const QString kdeconnectHandlerExecutable =
+                QStandardPaths::findExecutable(QStringLiteral("kdeconnect-handler"), {QCoreApplication::applicationDirPath()});
             if (!kdeconnectHandlerExecutable.isEmpty()) {
-                QProcess::startDetached(kdeconnectHandlerExecutable, { urlToShare });
+                QProcess::startDetached(kdeconnectHandlerExecutable, {urlToShare});
                 return 0; // exit the app once kdeconnect-handler is started
             }
         }
     }
 
+    qmlRegisterSingletonType("org.kde.kdeconnect.app", 1, 0, "About", [](QQmlEngine *engine, QJSEngine *) -> QJSValue {
+        return engine->toScriptValue(KAboutData::applicationData());
+    });
+
     QQmlApplicationEngine engine;
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
     engine.load(QUrl(QStringLiteral("qrc:/qml/main.qml")));
