@@ -1,21 +1,7 @@
 /**
- * Copyright 2015 Vineet Garg <grg.vineet@gmail.com>
+ * SPDX-FileCopyrightText: 2015 Vineet Garg <grg.vineet@gmail.com>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #include "bluetoothpairinghandler.h"
@@ -27,7 +13,7 @@
 #include "kdeconnectconfig.h"
 #include "networkpackettypes.h"
 
-BluetoothPairingHandler::BluetoothPairingHandler(DeviceLink* deviceLink)
+BluetoothPairingHandler::BluetoothPairingHandler(DeviceLink *deviceLink)
     : PairingHandler(deviceLink)
     , m_status(NotPaired)
 {
@@ -36,7 +22,7 @@ BluetoothPairingHandler::BluetoothPairingHandler(DeviceLink* deviceLink)
     connect(&m_pairingTimeout, &QTimer::timeout, this, &BluetoothPairingHandler::pairingTimeout);
 }
 
-void BluetoothPairingHandler::packetReceived(const NetworkPacket& np)
+void BluetoothPairingHandler::packetReceived(const NetworkPacket &np)
 {
     qCDebug(KDECONNECT_CORE) << "Pairing packet received!" << np.serialize();
 
@@ -45,16 +31,15 @@ void BluetoothPairingHandler::packetReceived(const NetworkPacket& np)
     bool wantsPair = np.get<bool>(QStringLiteral("pair"));
 
     if (wantsPair) {
-
-        if (isPairRequested())  { //We started pairing
+        if (isPairRequested()) { // We started pairing
 
             qCDebug(KDECONNECT_CORE) << "Pair answer";
             setInternalPairStatus(Paired);
-            
+
         } else {
             qCDebug(KDECONNECT_CORE) << "Pair request";
 
-            if (isPaired()) { //I'm already paired, but they think I'm not
+            if (isPaired()) { // I'm already paired, but they think I'm not
                 acceptPairing();
                 return;
             }
@@ -62,12 +47,12 @@ void BluetoothPairingHandler::packetReceived(const NetworkPacket& np)
             setInternalPairStatus(RequestedByPeer);
         }
 
-    } else { //wantsPair == false
+    } else { // wantsPair == false
 
         qCDebug(KDECONNECT_CORE) << "Unpair request";
 
         setInternalPairStatus(NotPaired);
-         if (isPairRequested()) {
+        if (isPairRequested()) {
             Q_EMIT pairingError(i18n("Canceled by other peer"));
         }
     }
@@ -76,18 +61,17 @@ void BluetoothPairingHandler::packetReceived(const NetworkPacket& np)
 bool BluetoothPairingHandler::requestPairing()
 {
     switch (m_status) {
-        case Paired:
-            Q_EMIT pairingError(i18n("%1: Already paired", deviceLink()->name()));
-            return false;
-        case Requested:
-            Q_EMIT pairingError(i18n("%1: Pairing already requested for this device", deviceLink()->name()));
-            return false;
-        case RequestedByPeer:
-            qCDebug(KDECONNECT_CORE) << deviceLink()->name() << " : Pairing already started by the other end, accepting their request.";
-            acceptPairing();
-            return false;
-        case NotPaired:
-            ;
+    case Paired:
+        Q_EMIT pairingError(i18n("%1: Already paired", deviceLink()->name()));
+        return false;
+    case Requested:
+        Q_EMIT pairingError(i18n("%1: Pairing already requested for this device", deviceLink()->name()));
+        return false;
+    case RequestedByPeer:
+        qCDebug(KDECONNECT_CORE) << deviceLink()->name() << " : Pairing already started by the other end, accepting their request.";
+        acceptPairing();
+        return false;
+    case NotPaired:;
     }
 
     NetworkPacket np(PACKET_TYPE_PAIR);
@@ -123,7 +107,8 @@ void BluetoothPairingHandler::rejectPairing()
     setInternalPairStatus(NotPaired);
 }
 
-void BluetoothPairingHandler::unpair() {
+void BluetoothPairingHandler::unpair()
+{
     NetworkPacket np(PACKET_TYPE_PAIR);
     np.set(QStringLiteral("pair"), false);
     deviceLink()->sendPacket(np);
@@ -135,7 +120,7 @@ void BluetoothPairingHandler::pairingTimeout()
     NetworkPacket np(PACKET_TYPE_PAIR);
     np.set(QStringLiteral("pair"), false);
     deviceLink()->sendPacket(np);
-    setInternalPairStatus(NotPaired); //Will emit the change as well
+    setInternalPairStatus(NotPaired); // Will emit the change as well
     Q_EMIT pairingError(i18n("Timed out"));
 }
 
@@ -144,7 +129,7 @@ void BluetoothPairingHandler::setInternalPairStatus(BluetoothPairingHandler::Int
     m_status = status;
     if (status == Paired) {
         deviceLink()->setPairStatus(DeviceLink::Paired);
-    } else if (status == NotPaired){
+    } else if (status == NotPaired) {
         deviceLink()->setPairStatus(DeviceLink::NotPaired);
     } else if (status == RequestedByPeer) {
         Q_EMIT deviceLink()->pairingRequest(this);
