@@ -4,23 +4,26 @@
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
+#include <QDebug>
 #include <QFile>
 #include <QIcon>
 #include <QStandardPaths>
-#include <QDebug>
 
 #include <iostream>
 
 #include <Windows.h>
 #include <tlhelp32.h>
 
-#include "indicatorhelper.h"
 #include "indicator_debug.h"
+#include "indicatorhelper.h"
 
-IndicatorHelper::IndicatorHelper(const QUrl& indicatorUrl)
-    : m_indicatorUrl(indicatorUrl) {}
+IndicatorHelper::IndicatorHelper(const QUrl &indicatorUrl)
+    : m_indicatorUrl(indicatorUrl)
+{
+}
 
-IndicatorHelper::~IndicatorHelper() {
+IndicatorHelper::~IndicatorHelper()
+{
     this->terminateProcess(processes::dbus_daemon, m_indicatorUrl);
     this->terminateProcess(processes::kdeconnect_app, m_indicatorUrl);
     this->terminateProcess(processes::kdeconnect_handler, m_indicatorUrl);
@@ -29,11 +32,17 @@ IndicatorHelper::~IndicatorHelper() {
     this->terminateProcess(processes::kdeconnect_daemon, m_indicatorUrl);
 }
 
-void IndicatorHelper::preInit() {}
+void IndicatorHelper::preInit()
+{
+}
 
-void IndicatorHelper::postInit() {}
+void IndicatorHelper::postInit()
+{
+}
 
-void IndicatorHelper::iconPathHook() {}
+void IndicatorHelper::iconPathHook()
+{
+}
 
 int IndicatorHelper::daemonHook(QProcess &kdeconnectd)
 {
@@ -53,7 +62,6 @@ void IndicatorHelper::systrayIconHook(KStatusNotifierItem &systray)
 }
 #endif
 
-
 bool IndicatorHelper::terminateProcess(const QString &processName, const QUrl &indicatorUrl) const
 {
     HANDLE hProcessSnap;
@@ -74,10 +82,9 @@ bool IndicatorHelper::terminateProcess(const QString &processName, const QUrl &i
         return FALSE;
     }
 
-    do
-    {
+    do {
         if (QString::fromWCharArray((wchar_t *)pe32.szExeFile) == processName) {
-            hProcess = OpenProcess( PROCESS_ALL_ACCESS, FALSE, pe32.th32ProcessID);
+            hProcess = OpenProcess(PROCESS_ALL_ACCESS, FALSE, pe32.th32ProcessID);
 
             if (hProcess == NULL) {
                 qCWarning(KDECONNECT_INDICATOR) << "Failed to get handle for the process:" << processName;
@@ -86,20 +93,12 @@ bool IndicatorHelper::terminateProcess(const QString &processName, const QUrl &i
                 const DWORD processPathSize = 4096;
                 CHAR processPathString[processPathSize];
 
-                BOOL gotProcessPath = QueryFullProcessImageNameA(
-                                hProcess,
-                                0,
-                                (LPSTR)processPathString,
-                                (PDWORD) &processPathSize
-                            );
+                BOOL gotProcessPath = QueryFullProcessImageNameA(hProcess, 0, (LPSTR)processPathString, (PDWORD)&processPathSize);
 
                 if (gotProcessPath) {
                     const QUrl processUrl = QUrl::fromLocalFile(QString::fromStdString(processPathString)); // to replace \\ with /
                     if (indicatorUrl.isParentOf(processUrl)) {
-                        BOOL terminateSuccess = TerminateProcess(
-                                                    hProcess,
-                                                    0
-                                                );
+                        BOOL terminateSuccess = TerminateProcess(hProcess, 0);
                         if (!terminateSuccess) {
                             qCWarning(KDECONNECT_INDICATOR) << "Failed to terminate process:" << processName;
                             return FALSE;
@@ -113,4 +112,3 @@ bool IndicatorHelper::terminateProcess(const QString &processName, const QUrl &i
     CloseHandle(hProcessSnap);
     return TRUE;
 }
-
